@@ -22,15 +22,15 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-"""Module for computing the orbital parameters of satellites.
-"""
+"""Module for computing the orbital parameters of satellites."""
 
+import logging
 import warnings
 from datetime import datetime, timedelta
 
+import numpy as np
 from scipy import optimize
 
-import numpy as np
 from pyorbital import astronomy, dt2np, tlefile
 
 try:
@@ -47,6 +47,8 @@ except ImportError:
     xr = None
     has_xarray = False
 
+logger = logging.getLogger(__name__)
+
 ECC_EPS = 1.0e-6  # Too low for computing further drops.
 ECC_LIMIT_LOW = -1.0e-3
 ECC_LIMIT_HIGH = 1.0 - ECC_EPS  # Too close to 1
@@ -206,9 +208,7 @@ class Orbital(object):
         return t_mid
 
     def get_position(self, utc_time, normalize=True):
-        """Get the cartesian position and velocity from the satellite.
-        """
-
+        """Get the cartesian position and velocity from the satellite."""
         kep = self._sgdp4.propagate(utc_time)
         pos, vel = kep2xyz(kep)
 
@@ -220,6 +220,7 @@ class Orbital(object):
 
     def get_lonlatalt(self, utc_time):
         """Calculate sublon, sublat and altitude of satellite.
+
         http://celestrak.com/columns/v02n03/
         """
         (pos_x, pos_y, pos_z), (vel_x, vel_y, vel_z) = self.get_position(
@@ -390,18 +391,24 @@ class Orbital(object):
             f_c = fun(c)
 
             x = b
+            with np.errstate(invalid='raise'):
+                while True:
+                    try:
+                        x = x - 0.5 * (((b - a) ** 2 * (f_b - f_c)
+                                        - (b - c) ** 2 * (f_b - f_a)) /
+                                       ((b - a) * (f_b - f_c) - (b - c) * (f_b - f_a)))
+                    except FloatingPointError:
+                        return b
+                    if abs(b - x) <= tol:
+                        return x
+                    f_x = fun(x)
+                    # sometimes the estimation diverges... return best guess
+                    if f_x > f_b:
+                        logger.info('Parabolic interpolation did not converge, returning best guess so far.')
+                        return b
 
-            while True:
-                x = x - 0.5 * (((b - a) ** 2 * (f_b - f_c)
-                                - (b - c) ** 2 * (f_b - f_a)) /
-                               ((b - a) * (f_b - f_c) - (b - c) * (f_b - f_a)))
-                if np.isnan(x):
-                    return b
-                if abs(b - x) <= tol:
-                    return x
-
-                a, b, c = (a + x) / 2.0, x, (x + c) / 2.0
-                f_a, f_b, f_c = fun(a), fun(b), fun(c)
+                    a, b, c = (a + x) / 2.0, x, (x + c) / 2.0
+                    f_a, f_b, f_c = fun(a), f_x, fun(c)
 
         # every minute
         times = utc_time + np.array([timedelta(minutes=minutes)
@@ -410,7 +417,6 @@ class Orbital(object):
         zcs = np.where(np.diff(np.sign(elev)))[0]
         res = []
         risetime = None
-        falltime = None
         for guess in zcs:
             horizon_mins = get_root(
                 elevation, guess, guess + 1.0, tol=tol / 60.0)
@@ -418,7 +424,6 @@ class Orbital(object):
             if elev[guess] < 0:
                 risetime = horizon_time
                 risemins = horizon_mins
-                falltime = None
             else:
                 falltime = horizon_time
                 fallmins = horizon_mins
@@ -544,8 +549,8 @@ class Orbital(object):
 
         try:
             tcross = optimize.bisect(_nprime,
-                                     a=np.datetime64(tstart, time_unit).astype(int),
-                                     b=np.datetime64(tend, time_unit).astype(int),
+                                     a=np.datetime64(tstart, time_unit).astype(np.int64),
+                                     b=np.datetime64(tend, time_unit).astype(np.int64),
                                      rtol=rtol)
         except ValueError:
             # Bisection did not converge
@@ -823,9 +828,9 @@ class _SGDP4(object):
             raise NotImplementedError('Deep space calculations not supported')
 
         if np.any(a < 1):
-            raise Exception('Satellite crased at time %s', utc_time)
+            raise Exception('Satellite crashed at time %s', utc_time)
         elif np.any(e < ECC_LIMIT_LOW):
-            raise ValueError('Satellite modified eccentricity to low: %s < %e'
+            raise ValueError('Satellite modified eccentricity too low: %s < %e'
                              % (str(e[e < ECC_LIMIT_LOW]), ECC_LIMIT_LOW))
 
         e = np.where(e < ECC_EPS, ECC_EPS, e)
