@@ -155,6 +155,18 @@ class Test(unittest.TestCase):
 
         self.assertTrue(len(res) == 15)
 
+    def test_get_next_passes_issue_22(self):
+        """Check that max"""
+        line1 = '1 28654U 05018A   21083.16603416  .00000102  00000-0  79268-4 0  9999'
+        line2 = '2 28654  99.0035 147.6583 0014816 159.4931 200.6838 14.12591533816498'
+
+        orb = orbital.Orbital("NOAA 18", line1=line1, line2=line2)
+        t = datetime(2021, 3, 9, 22)
+        next_passes = orb.get_next_passes(t, 1, -15.6335, 27.762, 0.)
+        rise, fall, max_elevation = next_passes[0]
+        assert rise < max_elevation < fall
+        print(next_passes)
+
     @mock.patch('pyorbital.orbital.Orbital.get_lonlatalt')
     def test_utc2local(self, get_lonlatalt):
         get_lonlatalt.return_value = -45, None, None
@@ -283,6 +295,22 @@ class TestGetObserverLook(unittest.TestCase):
         np.testing.assert_allclose(elev.data.compute(), self.exp_elev)
 
 
+class TestRegressions(unittest.TestCase):
+    """Test regressions."""
+
+    def test_63(self):
+        """Check that no runtimewarning is raised, #63."""
+        import warnings
+        from pyorbital.orbital import Orbital
+        from dateutil import parser
+        warnings.filterwarnings('error')
+        orb = Orbital("Suomi-NPP",
+                      line1="1 37849U 11061A   19292.84582509  .00000011  00000-0  25668-4 0  9997",
+                      line2="2 37849  98.7092 229.3263 0000715  98.5313 290.6262 14.19554485413345")
+        orb.get_next_passes(parser.parse("2019-10-21 16:00:00"), 12, 123.29736, -13.93763, 0)
+        warnings.filterwarnings('default')
+
+
 def suite():
     """The suite for test_orbital
     """
@@ -290,5 +318,6 @@ def suite():
     mysuite = unittest.TestSuite()
     mysuite.addTest(loader.loadTestsFromTestCase(Test))
     mysuite.addTest(loader.loadTestsFromTestCase(TestGetObserverLook))
+    mysuite.addTest(loader.loadTestsFromTestCase(TestRegressions))
 
     return mysuite
